/** reset */
/* 
  style.css contains a reset, font normalization and some base styles.
  
  credit is left where credit is due.
  additionally, much inspiration was taken from these projects:
    yui.yahooapis.com/2.8.1/build/base/base.css
    camendesign.com/design/
    praegnanz.de/weblog/htmlcssjs-kickstart
*/

/* 
  html5doctor.com Reset Stylesheet (Eric Meyer's Reset Reloaded + HTML5 baseline)
  v1.4 2009-07-27 | Authors: Eric Meyer & Richard Clark
  html5doctor.com/html-5-reset-stylesheet/
*/

html, body, div, span, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
abbr, address, cite, code,
del, dfn, em, img, ins, kbd, q, samp,
small, strong, sub, sup, var,
b, i,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, figure, footer, header, 
hgroup, menu, nav, section, menu,
time, mark, audio, video {
  margin:0;
  padding:0;
  border:0;
  outline:0;
  font-size:100%;
  vertical-align:baseline;
  background:transparent;
}                  

article, aside, figure, footer, header, 
hgroup, nav, section { display:block; }

ul { list-style:none; }

li {
    max-width: 48em;
}

blockquote, q { quotes:none; }

blockquote:before, blockquote:after,
q:before, q:after { content:''; content:none; }

a { margin:0; padding:0; font-size:100%; vertical-align:baseline; background:transparent; }

ins { background-color:#ff9; color:#000; text-decoration:none; }

mark { background-color:#ff9; color:#000; font-style:italic; font-weight:bold; }

del { text-decoration: line-through; }

abbr[title], dfn[title] { border-bottom:1px dotted #000; cursor:help; }

hr { display:block; height:1px; border:0; border-top:1px solid #ccc; margin:1em 0; padding:0; }

/* END RESET CSS */

a {
    color: #fff;
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

body {
    overflow-y: scroll;
    background: #000;
    margin: 0;
    padding: 0;
    color: #ddd;
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}

footer {
    margin-top: 2em;
    padding: 0 .25em;
    font-size: .75em;
    text-align: right;
}

    footer li {
        display: inline;
    }

nav {
    font-size: .75em;
    margin-bottom: .25em;
    padding: .5em;
    background: #333;
    box-shadow: 0 4px 2px #3F3F3F;
    text-transform: uppercase;
    overflow: auto;
}

    nav ul {
        overflow: auto;
    }

    nav li {
        float: left;
    }

    nav li.search {
        float: right;
        margin: 0;
        padding: 0;
    }

    nav a {
        padding: 2px;
    }

    nav input {
        font-size: .75em;
    }

ul {
    list-style: none;
    margin: 0;
    padding: 0;
}
    li {
        margin: .25em 1em .25em 0;
    }

.clear {
    float: none;
    clear: both;
}

.delete {
    color: #f00;
    font-size: .75em;
    font-weight: bold;
    padding: 2px;
    margin: 0 .5em 0 0;
}

.hint {
    color: #aaa;
}

#content {
    position: relative;
}

.page_navigator {
    text-align: right;
    font-size: .75em;
    text-transform: uppercase;
}

    .page_navigator img {
        vertical-align: bottom;
    }

#map {
    background: #333333;
    border-bottom-right-radius: 10px;
    border-top-right-radius: 10px;
    font-size: 0.75em;
    margin: 1em 0;
    padding: 0.25em;
    position: fixed;
    width: 6em;
    white-space: nowrap;
}

#filters {
    font-size: .75em; 
    margin: .25em 0 .5em 10em;
    padding: 0 0 .25em 0;
    border-bottom: 1px solid #333;
}

    #filters li {
        padding-left: 1em;
    }

    #filters a:hover {
        text-decoration: none;
    }

    #filters img {
        vertical-align: bottom;
        padding: 0 4px 0 0 ;
    }

#records {
    padding: .5em 0;
}

    .record {
        cursor: pointer;
        padding-left: 10em;
        border: 1px solid transparent;
    }

        .record.highlight {
            border-left: 1px solid #999;
            border-right: 1px solid #999;
        }

        .record.highlight-first {
            border-top: 1px solid #999;
        }

        .record.highlight-last {
            border-bottom: 1px solid #999;
        }

        .timestamp {
            float: left;
            clear: left;
            color: #777;
            padding: .25em 0 .5em 0;
            font-size: .75em;
            font-family: Menlo, Courier, monospace;
            white-space: nowrap;
        }

        .detail {
            float: left;
            clear: right;
            max-width: 80%;
            padding: 0 0 .5em 1em;
        }

            .detail.critical .message,
            .detail.error .message {
                color: #f30;
            }

            .detail.warn .message {
                color: #fc3;
            }

            .detail .meta {
                font-size: .75em; 
                padding-top: .25em;
                display: none;
            }

            .detail .meta div {
                float: left;
                margin: .25em .5em .25em 0;
            }

            .detail .meta div.debug,
            .detail .meta div.debug {
                float: none;
                clear: both;
            }

                .detail .meta div.debug a {
                    color: #fff;
                }
        
@media print {
    nav { display: none; }
}
